# Welcome to ginRex's documentation!

Analyse program ... TODO

## Documentation
+ API documentation can be generated by using Sphinx. Build via
```
sphinx-build -b html doc/ doc/_build/html
```

## Git
+ ginRex is located on two repositories simultaneously. Pushing it to both requires following:<br>
For gitlab (main):
```
git remote set-url --add --push origin https://git.uni-wuppertal.de/ag-dlh/reflexafs-data-pipeline.git
```
For github (remote):
```
git remote set-url --add --push origin https://github.com/San-WierPa/ginRex.git
```
Finally, git push (here: both branches are called development):
```
git push origin development
```

## TODO
+ 14.08.2021:
  + setup the setup.py
+ 15.08.2021:
  + install and go through Poetry (?) or just manually (?)
+ 23.08.2021:
  + wrapper?
  + Qt6
  + Implement T-Rex "idea"
  + Sphinx
    + use docstring for doc of API
    + Configfile -> self written pages
  + Workflow
    + Input -> what is and which datatype
    + Output -> what is the goal, which datatype 
    + Mathematic/Algorithm -> what is necessary / what are logical sections
    + These sections deliver the process-diagram
    + which parts need implementation / which parts can be covered by libraries
+ 24.08.2021:
  + Start main functionality of xraylarch through ginRex
  + Go online w/ the program
